bringObjectTS: bringObjectTS brings objects that represent time series into...

Description Usage Arguments Value Author(s)

View source: R/bringObjectTS.R

Description

bringObjectTS brings objects that represent time series into a list

Usage

1
bringObjectTS(path, rastersNamePattern)

Arguments

path

path to the directory containing the files to be brought as list.

rastersNamePattern

Character vector of the name pattern to be used for the search.

Value

A list of the objects that were read from disk. Currently the function only works with '.tif' (i.e. raster) and '.rds' objects.

Author(s)

Tati Micheletti


tati-micheletti/usefun documentation built on June 29, 2020, 9:31 a.m.