string. Used for printing, it tell us what are the
values of the two vectors (use plural form). Default value: "nodes".
with.gt
logical. Determines if the ">" sign will be appended for nice
printing in an R notebook (use with the chuck option results = 'asis').
Default value: TRUE.
Value
the vector of the common values. If there is only one value
in common, the vector.values.str gets the last character stripped for
readability. If there are no common values, it returns NULL.