powered by
A function to test whether an object is empty. It checks the length of the object, so it has different behaviour than is.null.
is.null
is_empty(obj)
a general object
a logical specifying if the object is NULL or not.
# NOT RUN { # TRUE is_empty(NULL) is_empty(c()) # FALSE is_empty("") is_empty(NA) is_empty(NaN) # }
Run the code above in your browser using DataLab