Check if two matrices are equal. Equality is defined by both of them being
matrices in the first place, having the same dimensions as well as the same
elements.
Usage
mat_equal(x, y)
Arguments
x, y
matrices
Value
a logical specifying if the two matrices are equal or not.