Learn R Programming

usefun (version 0.4.1)

plot_string_to_file: Plot string to output format

Description

Execute a plot string expression and output the result to the specified file format.

Usage

plot_string_to_file(file, file.format = c("pdf", "png", "svg", "tiff"),
  plot.string)

Arguments

file

string. The name of the file, can be a full path.

file.format

string. The output file format. Can be one of these: pdf, svg, png or tiff.

plot.string

string. The plot string expression.

Examples

Run this code
# NOT RUN {
x = 1:10
y = 1:10
plot_string_to_file(paste0(tempdir(), "/my_file.pdf"), "pdf", "plot(x,y)")

# }

Run the code above in your browser using DataLab