Prints a bold string only when `html.output` is enabled. Otherwise, it prints a normal string. The the ">" sign can be appended if nice output in an R notebook is desired.
pretty_print_bold_string(string, with.gt = TRUE, html.output = TRUE)a string
logical. Determines if the ">" sign will be appended for nice printing in an R notebook. Default value: TRUE.
logical. If TRUE, it encapsulates the string with the bold tags for an HTML document. Default value: TRUE.