Learn R Programming

usefun (version 0.4.1)

pretty_print_name_and_value: Pretty print a name and value

Description

Pretty print a name and value

Usage

pretty_print_name_and_value(name, value, with.gt = FALSE,
  with.comma = TRUE)

Arguments

name

string

value

string

with.gt

logical. Determines if the ">" sign will be appended for nice printing in an R notebook. Default value: FALSE.

with.comma

logical. Determines if the comma (,) character will be appended to the end of the output. Default value: TRUE.

Examples

Run this code
# NOT RUN {
pretty_print_name_and_value("aName", "aValue", with.gt = TRUE)
pretty_print_name_and_value("aName", "aValue", with.comma = FALSE)
# }

Run the code above in your browser using DataLab