It outputs a vector's names and values in this format: name1: value1, name2: value2,.... You can choose how many elements to show in this format.
pretty_print_vector_names_and_values(vec, n = -1)vector with names attribute
the number of elements that you want to print in a nice way. Default value: -1 (pretty print all elements). For any n < 1, all elements are printed.