Pretty printing of a vector's values
pretty_print_vector_values(vec, vector.values.str = "nodes",
sep = ", ", with.gt = TRUE)vector
string. It tell us what are the values of the vector (use plural form) in order to fill the print message. Default value: "nodes".
string. The separator character to use to distinguish between the vector values. Default value: ", ".
logical. Determines if the ">" sign will be appended for nice printing in an R notebook. Default value: TRUE.