Learn R Programming

usefun (version 0.4.1)

remove_commented_and_empty_lines: Remove commented and empty lines

Description

Removes empty or commented lines from a character vector (each element being a line)

Usage

remove_commented_and_empty_lines(lines)

Arguments

lines

a character vector, usually the result from using the readLines function

Value

a character vector of the pruned lines