save_vector_to_file: Save vector to a specified file
Description
Function for saving a vector with or without its row names to a
specified file.
Usage
save_vector_to_file(vector, file, with.row.names = FALSE)
Arguments
file
string. The name of the file, can be a full path.
with.row.names
logical. If TRUE, then the names(vector) will be
included in the output file. Default value: FALSE.