Description Usage Arguments Value Author(s)
View source: R/bringObjectTS.R
bringObjectTS brings objects that represent time series into a list
1 | bringObjectTS(path, rastersNamePattern)
|
path |
path to the directory containing the files to be brought as list. |
rastersNamePattern |
Character vector of the name pattern to be used for the search. |
A list of the objects that were read from disk. Currently the function only works with '.tif' (i.e. raster) and '.rds' objects.
Tati Micheletti
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.