powered by
Pretty print a name and value
pretty_print_name_and_value(name, value, with.gt = FALSE, with.comma = TRUE)
string
logical. Determines if the ">" sign will be appended for nice printing in an R notebook. Default value: FALSE.
logical. Determines if the comma (,) character will be appended to the end of the output. Default value: TRUE.
# NOT RUN { pretty_print_name_and_value("aName", "aValue", with.gt = TRUE) pretty_print_name_and_value("aName", "aValue", with.comma = FALSE) # }
Run the code above in your browser using DataLab