powered by
Use this function to transform a given decimal number to the desired precision by choosing the number of digits after the decimal point.
specify_decimal(number, digits.to.keep)
numeric
numeric. Refers to the digits to keep after decimal point '.'. This value should be 15 or less.
the pruned number in string format
# NOT RUN { # 0.123 specify_decimal(0.1233213, 3) # }
Run the code above in your browser using DataLab